# pypydata
copy of pydata

## Installation
```
pip install pypydata
```

## Usage
```
usage: pypydata [-l]

Location list PypyData

optional arguments:
  -h, --help  show this help message and exit
  -l          You can see lists of all PyData location.
```
